@@ -181,8 +181,15 @@ class WalkSFTP:
             while True:
                 count+=1
                 try:
+                    
                     transport = _FastTransport((self._base_url, self._port))
-                    transport.connect(username = self._username, password = self._password)
+                    if self._failed_key: 
+                        transport = paramiko.SSHClient()
+                        transport.set_missing_host_key_policy(paramiko.AutoAddPolicy())
+                        transport.connect(self._base_url, username = self._username, password = self._password)
+                    else:    
+                        transport.connect(username = self._username, password = self._password)
+                        
                     sftp = paramiko.SFTPClient.from_transport(transport)
 
                     s = pysftp.Connection(
@@ -455,9 +462,16 @@ class WalkSFTP:
         
         
     def create_pysftp_host_key(self):
-        ssh_key = os.popen('ssh-keyscan {}'.format(self._base_url)).read().split(' ')
-        self.cnopts = pysftp.CnOpts()
-        
-        keydata = ssh_key[2].encode()
-        key = paramiko.RSAKey(data= decodebytes(keydata))
-        self.cnopts.hostkeys.add(ssh_key[0],ssh_key[1],key)
\ No newline at end of file
+        keydata = None
+        try:
+            ssh_key = os.popen('ssh-keyscan {}'.format(self._base_url)).read().split(' ')
+            self.cnopts = pysftp.CnOpts()
+            keydata = ssh_key[2].encode()
+            decode_key = decodebytes(keydata)
+            key = paramiko.RSAKey(data=decode_key)
+            self.cnopts.hostkeys.add(ssh_key[0],ssh_key[1],key)
+            self._failed_key=False
+        except Exception as e:
+            print('may have failed to add key: {}'.format(keydata))
+            print(e)
+            self._failed_key=True
\ No newline at end of file
